EasyExtend.langlets.p4d.p4dbase.FileLike

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase :: Class FileLike |
[hide private]
[frames] | no frames]

# Class FileLike

    object --+
             |
            FileLike

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
write(self, s) |
__repr__(self) repr(x) |
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)